@@ -1124,9 +1124,13 @@ table_canvas_focus_event_cb (GtkWidget *widget, GdkEventFocus *event, gpointer d
 		gnome_canvas_item_grab_focus (etable->click_to_add);
 	} else if (!canvas->focused_item && etable->group) {
         	focus_first_etable_item (etable->group);
+	} else if (canvas->focused_item) {
+		ESelectionModel *selection = (ESelectionModel *)etable->selection;
+		if (e_selection_model_cursor_row (selection) == -1)
+			focus_first_etable_item (etable->group);
 	}
 
-	return FALSE;
+	return TRUE;
 }
 
 static gboolean
@@ -1174,7 +1178,7 @@ click_to_add_event (ETableClickToAdd *etcta, GdkEventKey *key, ETable *etable)
 			return FALSE;
 	}
 
-	return TRUE;
+	return FALSE;
 }
 
 static void
@@ -2388,11 +2392,13 @@ e_table_get_cell_geometry (ETable *table,
 
 	e_table_group_get_cell_geometry(table->group, &row, &col, x_return, y_return, width_return, height_return);
 
-	if (x_return)
+	if (x_return && table->table_canvas)
 		(*x_return) -= GTK_LAYOUT(table->table_canvas)->hadjustment->value;
 	if (y_return) {
-		(*y_return) -= GTK_LAYOUT(table->table_canvas)->vadjustment->value;
-		(*y_return) += GTK_WIDGET(table->header_canvas)->allocation.height;
+		if (table->table_canvas)
+			(*y_return) -= GTK_LAYOUT(table->table_canvas)->vadjustment->value;
+		if (table->header_canvas)
+			(*y_return) += GTK_WIDGET(table->header_canvas)->allocation.height;
 	}
 }
 
